/**
 * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
 *
 * The contents of this file are subject to the terms of the Liferay Enterprise
 * Subscription License ("License"). You may not use this file except in
 * compliance with the License. You can obtain a copy of the License by
 * contacting Liferay, Inc. See the License for the specific language governing
 * permissions and limitations under the License, including but not limited to
 * distribution rights of the Software.
 *
 *
 *
 */

package com.liferay.portal.tika.internal.util;

import com.liferay.petra.process.ProcessConfig;
import com.liferay.petra.string.StringBundler;
import com.liferay.portal.kernel.util.AggregateClassLoader;
import com.liferay.portal.kernel.util.PortalClassLoaderUtil;
import com.liferay.portal.util.PortalClassPathUtil;

import java.io.File;

import java.net.URL;

import java.security.CodeSource;
import java.security.ProtectionDomain;

import org.apache.tika.Tika;

/**
 * @author Shuyang Zhou
 */
public class ProcessConfigUtil {

	public static ProcessConfig getProcessConfig() {
		return _processConfig;
	}

	private static void _appendBundleClassPath(StringBundler sb) {
		ProtectionDomain protectionDomain = Tika.class.getProtectionDomain();

		CodeSource codeSource = protectionDomain.getCodeSource();

		URL url = codeSource.getLocation();

		File file = new File(url.getFile());

		File cpLibFolder = file.getParentFile();

		for (File cpLibFile : cpLibFolder.listFiles()) {
			sb.append(cpLibFile.getAbsolutePath());
			sb.append(File.pathSeparator);
		}
	}

	private static String _getSelfJarPath() {
		ProtectionDomain protectionDomain =
			ProcessConfigUtil.class.getProtectionDomain();

		CodeSource codeSource = protectionDomain.getCodeSource();

		URL url = codeSource.getLocation();

		return url.getFile();
	}

	private static final ProcessConfig _processConfig;

	static {
		ProcessConfig portalProcessConfig =
			PortalClassPathUtil.getPortalProcessConfig();

		ProcessConfig.Builder builder = new ProcessConfig.Builder(
			portalProcessConfig);

		StringBundler sb = new StringBundler();

		sb.append(_getSelfJarPath());
		sb.append(File.pathSeparator);

		_appendBundleClassPath(sb);

		sb.append(portalProcessConfig.getRuntimeClassPath());

		builder.setRuntimeClassPath(sb.toString());

		builder.setReactClassLoader(
			AggregateClassLoader.getAggregateClassLoader(
				PortalClassLoaderUtil.getClassLoader(),
				ProcessConfigUtil.class.getClassLoader()));

		_processConfig = builder.build();
	}

}